# -*- coding: utf-8 -*-

from django.shortcuts import get_object_or_404, render_to_response
from django.template import RequestContext
from django.contrib.auth.decorators import login_required
from django.http import HttpResponseRedirect
from django.utils.translation import ugettext_lazy as _
from django.shortcuts import redirect
from django.contrib.sites.models import Site
import models as mymodels
import forms as myforms

from django.conf import settings as conf

from django.views.generic import DetailView, ListView


class Photos(ListView):

    template_name = "rgallery/photos.html"
    context_object_name = "photos"
    paginate_by = 51

    def get_queryset(self):
        return mymodels.Photo.objects.all().filter(status=1).order_by('-capture_date')

    def get_context_data(self, **kwargs):
        context = super(Photos, self).get_context_data(**kwargs)
        context.update({
            'title': _(u'Photos'),
        })
        return context


class Videos(ListView):

    template_name = "rgallery/videos.html"
    context_object_name = "videos"
    paginate_by = 6

    def get_queryset(self):
        vid = mymodels.Video.objects.all().filter(status=1).order_by('-capture_date')
        print vid
        return vid

    def get_context_data(self, **kwargs):
        context = super(Videos, self).get_context_data(**kwargs)
        context.update({
            'title': _(u'Videos'),
        })
        return context


# -*- coding: utf-8 -*-

from django.conf.urls.defaults import *
from rgallery.views import Photos, Videos

urlpatterns = patterns('',
    url(r'^$',                              Photos.as_view(), {}, 'app_gallery-gallery'),
    url(r'^page/(?P<page>\d+)/$',           Photos.as_view(), {}, 'app_gallery-gallery-page'),
    url(r'^videos/$',                       Videos.as_view(), {}, 'app_gallery-videos'),
    url(r'^videos/page/(?P<page>\d+)/$',    Videos.as_view(), {}, 'app_gallery-videos-page'),
)



# -*- coding: utf-8 -*-

"""
Models for the "flatpages" project
"""

import time
import socket
from django.db import models
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _
from django.contrib.contenttypes import generic
from django.template.defaultfilters import slugify
from django.conf import settings as conf


class Photo(models.Model):

    """
    Modelo que define una foto.
    """

    image = models.ImageField(_('Imagen'), upload_to='uploads/photos/', blank=True)
    origen = models.CharField(_('Archivo origen'), max_length=255)
    insert_date = models.DateTimeField(_(u'Fecha de inserción'))
    capture_date = models.DateTimeField(_(u'Fecha de la foto'))
    status =  models.BooleanField(_('Status'), default=True)

    def __unicode__(self):
        return str(self.image)

    class Meta:
        verbose_name = _('Foto')
        verbose_name_plural = _('Fotos')


class Video(models.Model):

    """
    Modelo que define un video.
    """

    title = models.CharField(_('Title'), max_length=255)
    image = models.ImageField(_('Imagen'), upload_to='uploads/photos_videos/', blank=True)
    video = models.FileField(_('Video'), upload_to='uploads/videos/', blank=True)
    origen = models.CharField(_('Archivo origen'), max_length=255)
    insert_date = models.DateTimeField(_(u'Fecha de inserción'))
    capture_date = models.DateTimeField(_(u'Fecha de la foto'))
    status =  models.BooleanField(_('Status'), default=True)

    def __unicode__(self):
        return str(self.title)

    class Meta:
        verbose_name = _('Video')
        verbose_name_plural = _('Videos')
